@@ -101,6 +101,9 @@ class Connection(object):
         self.security_protocol = self.driver_conf.security_protocol
         self.sasl_mechanism = self.driver_conf.sasl_mechanism
         self.ssl_cafile = self.driver_conf.ssl_cafile
+        self.ssl_client_cert_file = self.driver_conf.ssl_client_cert_file
+        self.ssl_client_key_file = self.driver_conf.ssl_client_key_file
+        self.ssl_client_key_password = self.driver_conf.ssl_client_key_password
         self.url = url
         self.virtual_host = url.virtual_host
         self._parse_url()
@@ -238,6 +241,9 @@ class ConsumerConnection(Connection):
             'sasl.username': self.username,
             'sasl.password': self.password,
             'ssl.ca.location': self.ssl_cafile,
+            'ssl.certificate.location': self.ssl_client_cert_file,
+            'ssl.key.location': self.ssl_client_key_file,
+            'ssl.key.password': self.ssl_client_key_password,
             'enable.partition.eof': False,
             'default.topic.config': {'auto.offset.reset': 'latest'}
         }
@@ -255,6 +261,7 @@ class ProducerConnection(Connection):
         super(ProducerConnection, self).__init__(conf, url)
         self.batch_size = self.driver_conf.producer_batch_size
         self.linger_ms = self.driver_conf.producer_batch_timeout * 1000
+        self.compression_codec = self.driver_conf.compression_codec
         self.producer = None
         self.producer_lock = threading.Lock()
 
@@ -317,11 +324,15 @@ class ProducerConnection(Connection):
                 'bootstrap.servers': ",".join(self.hostaddrs),
                 'linger.ms': self.linger_ms,
                 'batch.num.messages': self.batch_size,
+                'compression.codec': self.compression_codec,
                 'security.protocol': self.security_protocol,
                 'sasl.mechanism': self.sasl_mechanism,
                 'sasl.username': self.username,
                 'sasl.password': self.password,
-                'ssl.ca.location': self.ssl_cafile
+                'ssl.ca.location': self.ssl_cafile,
+                'ssl.certificate.location': self.ssl_client_cert_file,
+                'ssl.key.location': self.ssl_client_key_file,
+                'ssl.key.password': self.ssl_client_key_password
             }
             self.producer = confluent_kafka.Producer(conf)
 
@@ -345,7 +356,7 @@ class KafkaListener(base.PollStyleListener):
 
     def __init__(self, conn):
         super(KafkaListener, self).__init__()
-        self._stopped = threading.Event()
+        self._stopped = eventletutils.Event()
         self.conn = conn
         self.incoming_queue = []
 
@@ -399,7 +410,7 @@ class KafkaDriver(base.BaseDriver):
         LOG.info("Kafka messaging driver shutdown")
 
     def send(self, target, ctxt, message, wait_for_reply=None, timeout=None,
-             call_monitor_timeout=None, retry=None):
+             call_monitor_timeout=None, retry=None, transport_options=None):
         raise NotImplementedError(
             'The RPC implementation for Kafka is not implemented')
 
