@@ -14,30 +14,17 @@
 
 import abc
 import collections
-import sys
 import threading
 
 from oslo_log import log as logging
 from oslo_utils import timeutils
-import six
 
 from oslo_messaging._drivers import common
 
 LOG = logging.getLogger(__name__)
 
-# TODO(harlowja): remove this when we no longer have to support 2.7
-if sys.version_info[0:2] < (3, 2):
-    def wait_condition(cond):
-        # FIXME(markmc): timeout needed to allow keyboard interrupt
-        # http://bugs.python.org/issue8844
-        cond.wait(timeout=1)
-else:
-    def wait_condition(cond):
-        cond.wait()
 
-
-@six.add_metaclass(abc.ABCMeta)
-class Pool(object):
+class Pool(object, metaclass=abc.ABCMeta):
     """A thread-safe object pool.
 
     Modelled after the eventlet.pools.Pool interface, but designed to be safe
@@ -104,7 +91,7 @@ class Pool(object):
                             "current size %s surpasses max "
                             "configured rpc_conn_pool_size %s",
                             self._current_size, self._max_size)
-                wait_condition(self._cond)
+                self._cond.wait()
 
         # We've grabbed a slot and dropped the lock, now do the creation
         try:
