@@ -23,7 +23,7 @@ import oslo_messaging
 from oslo_messaging.notify import dispatcher
 from oslo_messaging.notify import notifier as msg_notifier
 from oslo_messaging.tests import utils as test_utils
-from six.moves import mock
+from unittest import mock
 
 load_tests = testscenarios.load_tests_apply_scenarios
 
@@ -42,7 +42,7 @@ class RestartableServerThread(object):
         if self.thread is not None:
             self.thread.stop()
             self.thread.join(timeout=15)
-            ret = self.thread.isAlive()
+            ret = self.thread.is_alive()
             self.thread = None
             return ret
         return True
